@@ -20,6 +20,7 @@ import argparse
 import datetime
 import json
 import logging
+import re
 import subprocess
 import sys
 from collections import defaultdict
@@ -41,10 +42,7 @@ from . import __version__
 try:
     from htcondor import HTCondorException
 except ImportError:  # htcondor < 8.9.0
-    HTCONDOR_8_8 = True
     HTCondorException = RuntimeError
-else:
-    HTCONDOR_8_8 = False
 
 __author__ = "Duncan Macleod <duncan.macleod@ligo.org>"
 
@@ -75,6 +73,7 @@ IGWN_TAG_CLASSAD = "LigoSearchTag"
 HISTORY_CLASSADS = [
     IGWN_USER_CLASSAD,
     IGWN_TAG_CLASSAD,
+    "AccountingGroup",
     "CompletionDate",
     "CpusProvisioned",
     "CumulativeSuspensionTime",
@@ -328,6 +327,60 @@ def create_parser():
 
 # -- condor interactions ----
 
+def get_condor_version(executable=None):
+    """Call condor_version and return the output
+
+    Parameters
+    ----------
+    executable : `str`, optional
+        the path to the condor_version executable to call,
+        defaults to the first one on the ``PATH``
+
+    Returns
+    -------
+    text : `str`
+        the decoded text from ``condor_version``
+
+    Examples
+    --------
+    >>> print(get_condor_version())
+    $CondorVersion: 8.8.5 Sep 04 2019 BuildID: 480168 PackageID: 8.8.5-1 $
+    $CondorPlatform: x86_64_RedHat7 $
+    """
+    return subprocess.check_output(
+        [executable or which("condor_version")],
+    ).decode("utf-8").strip()
+
+
+def get_condor_version_number(executable=None):
+    """Call condor_version and return the version number.
+
+    Parameters
+    ----------
+    executable : `str`, optional
+        the path to the condor_version executable to call,
+        defaults to the first one on the ``PATH``
+
+    Returns
+    -------
+    version : `str`
+        the version number stripped from the output of ``condor_version``
+
+    See also
+    --------
+    get_condor_version
+        for details of the call to ``condor_version``
+
+    Examples
+    --------
+    >>> print(get_condor_version_number())
+    8.8.5
+    """
+    raw = get_condor_version(executable=executable)
+    cvregex = re.compile(r"(\s|\A)(\d+\.\d+\.\d+([a-z0-9]+)?)(\s|\Z)")
+    return cvregex.search(raw).group().strip()
+
+
 def find_schedulers(pool=None):
     """Returns the names of all schedulers known by the condor collector
     """
@@ -453,6 +506,8 @@ def _get_history_subprocess(
         pool,
         file=None,
 ):
+    condor_version = get_condor_version_number()
+    htcondor_89 = condor_version >= "8.9.0"
     cmd = [
         which("condor_history"),
         "-constraint", constraint,
@@ -461,7 +516,7 @@ def _get_history_subprocess(
         cmd.extend(("-since", since))
     if schedname != getfqdn():
         cmd.extend(("-name", schedname))
-    if not HTCONDOR_8_8:  # htcondor >=8.9.0
+    if htcondor_89:  # htcondor >=8.9.0
         cmd.extend(["-jsonl", "-af"] + classads)
     else:  # htcondor < 8.9.0
         cmd.extend(_format_condor_history_classads(classads))
@@ -480,7 +535,7 @@ def _get_history_subprocess(
             check=True,
     ).stdout.splitlines():
         data = load_json(line.decode("utf-8"))
-        if HTCONDOR_8_8:  # htcondor < 8.9.0
+        if not htcondor_89:  # htcondor < 8.9.0
             for key in list(data.keys()):
                 if data[key] == "undefined":  # just ignore undefined classads
                     del data[key]
@@ -585,10 +640,7 @@ def get_run_metadata():
     Mainly for debugging issues with the data.
     """
     if Path("/usr/bin/condor_version").exists():
-        system_condor_version = subprocess.check_output(
-            ["/usr/bin/condor_version"],
-            encoding="utf-8",
-        )
+        system_condor_version = get_condor_version("/usr/bin/condor_version")
     else:
         system_condor_version = None
     return {
